#!/usr/bin/env python
import os

import click
import helpers

# Check the required configuration files exist, and create defaults if not.
helpers.check_install()


def echo_data(data):
    for data_key, data_value in data.items():
        click.echo("%s = %s" % (data_key, data_value))


@click.group()
def cli():
    pass


@click.command()
@click.argument('entry_id')
@click.argument('local_path')
@click.argument('remote_path')
def add(entry_id, local_path, remote_path):
    """Add a new entry."""
    helpers.add_entry({
        "id": entry_id,
        "local": local_path,
        "remote": remote_path
    })
    click.echo("Added new entry: %s" % entry_id)


@click.command('rm')
@click.argument('entry_id')
def remove(entry_id):
    """Remove an entry."""
    try:
        helpers.remove_entry(entry_id)
        click.echo("Deleted entry: %s" % entry_id)
    except KeyError:
        click.echo("ERROR: No entry found with id: %s." % entry_id)


@click.command('list')
def list_entries():
    """List all entries."""
    config = helpers.load_config()

    click.echo('\n==== Entries ====\n')
    for entry_id, entry_data in config['entries'].items():
        click.echo("[%s]" % entry_id)
        echo_data(entry_data)
        click.echo("\n")


@click.command()
@click.argument('entry_id')
@click.option('--dry/--execute', default=False, help='Run rclone sync with --dry-run flag.')
def pull(entry_id, dry):
    """Sync local to match remote."""
    config = helpers.load_config()
    entry = config['entries'][entry_id]

    if dry:
        os.system("rclone sync %s %s --dry-run" % (entry['remote'], entry['local']))
    else:
        os.system("rclone sync %s %s --progress" % (entry['remote'], entry['local']))


@click.command()
@click.argument('entry_id')
@click.option('--dry/--execute', default=False, help='Run rclone sync with --dry-run flag.')
def push(entry_id, dry):
    """Sync remote to match local."""
    config = helpers.load_config()
    entry = config['entries'][entry_id]

    if dry:
        os.system("rclone sync %s %s --dry-run" % (entry['local'], entry['remote']))
    else:
        os.system("rclone sync %s %s  --progress" % (entry['local'], entry['remote']))


@click.command()
@click.argument('entry_id')
def diff(entry_id):
    """Show the difference between the local and remote."""
    config = helpers.load_config()
    entry = config['entries'][entry_id]

    os.system("rclone check %s %s --dry-run" % (entry['local'], entry['remote']))


cli.add_command(add)
cli.add_command(remove)
cli.add_command(list_entries)
cli.add_command(pull)
cli.add_command(push)
cli.add_command(diff)


if __name__ == '__main__':
    cli()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='rcl',
    version='0.1.2',
    author='Ben Ryder',
    author_email='dev@benryder.me',
    description='A simple command line wrapper for rclone focused on easy folder syncing',
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=['rclone', 'rclone-wrapper'],
    url='https://github.com/Ben-Ryder/rcl',
    download_url='https://github.com/Ben-Ryder/rcl/archive/v0.1.2.tar.gz',
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=[
        'Click',
        'toml'
    ],
    entry_points='''
        [console_scripts]
        rcl=rcl.main:cli
    ''',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: POSIX :: Linux',
        'Operating System :: MacOS',
    ],
    license='GPLV3',
)



import os
import toml


CONFIG_FILE = os.path.expanduser("~") + "/.rcl-config"
DEFAULT_CONFIG = {'entries': {}}


def check_install():
    if not os.path.isfile(CONFIG_FILE):
        save_config(DEFAULT_CONFIG)


def save_config(config):
    """ Saves the configuration. OVERWRITES CURRENT CONFIG """
    with open(CONFIG_FILE, "w") as config_file:
        toml.dump(config, config_file)


def load_config():
    """ Loads the configuration. """
    return toml.load(CONFIG_FILE)


def add_entry(entry):
    config = load_config()
    config['entries'][entry['id']] = entry
    save_config(config)


def remove_entry(entry_id):
    config = load_config()
    del config['entries'][entry_id]
    save_config(config)
